==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/PageChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PageChangedEventArgsDescription } from "./PageChangedEventArgsDescription";
/**
 * @hidden
 */
export let PageChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class PageChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (PageChangedEventArgsDescriptionMetadata.a == null) {
                PageChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PageChangedEventArgsDescriptionMetadata.c(PageChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(PageChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(PageChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Page", "Number:int");
            a.item("DataRef", "(w:Data,wf:Data)DataRef:object");
        }
        static d(a) {
            PageChangedEventArgsDescriptionMetadata.b(a);
            a.aa("PageChangedEventArgs", () => new PageChangedEventArgsDescription());
            a.z("PageChangedEventArgs", PageChangedEventArgsDescriptionMetadata.a);
        }
    }
    PageChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(PageChangedEventArgsDescriptionMetadata, 'PageChangedEventArgsDescriptionMetadata');
    PageChangedEventArgsDescriptionMetadata.a = null;
    return PageChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/PageChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PageChangedEventArgsDescription } from "./PageChangedEventArgsDescription";
/**
 * @hidden
 */
export let PageChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class PageChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (PageChangedEventArgsDescriptionMetadata.a == null) {
                PageChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PageChangedEventArgsDescriptionMetadata.c(PageChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(PageChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(PageChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Page", "Number:int");
            a.item("DataRef", "(w:Data,wf:Data)DataRef:object");
        }
        static d(a) {
            PageChangedEventArgsDescriptionMetadata.b(a);
            a.ac("PageChangedEventArgs", () => new PageChangedEventArgsDescription());
            a.ab("PageChangedEventArgs", PageChangedEventArgsDescriptionMetadata.a);
        }
    }
    PageChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(PageChangedEventArgsDescriptionMetadata, 'PageChangedEventArgsDescriptionMetadata');
    PageChangedEventArgsDescriptionMetadata.a = null;
    return PageChangedEventArgsDescriptionMetadata;
})();
